# PmPy - Project Management in python

![Github Workflow Deploy Package](https://img.shields.io/github/workflow/status/Project-PmPy/pmpy/Upload%20Python%20Package?label=deploy)
![Github Release Version](https://img.shields.io/github/v/release/Project-PmPy/pmpy)
![Github Release Date](https://img.shields.io/github/release-date/project-pmpy/pmpy)
![PyPi Package Version](https://img.shields.io/pypi/v/pmpy)
![PyPi Package Downloads](https://img.shields.io/pypi/dm/pmpy)
![Github License](https://img.shields.io/github/license/project-pmpy/pmpy)
![Github Issues](https://img.shields.io/github/issues/project-pmpy/pmpy)
![Github Pull Requests](https://img.shields.io/github/issues-pr/project-pmpy/pmpy)

PmPy offers project management tools in python.

## Using Pmpy
Getting started quickly:
```
pip install pmpy
```
## Community
- [Github Discussions](https://github.com/project-pmpy/pmpy/discussions)

## Contributing back to PmPy
If you run into an issue, please file a new [issue](https://github.com/project-pmpy/pmpy/issues) for us to discuss. If possible, follow up with a pull request.

If you would like to add a feature, please reach out via [issue](https://github.com/project-pmpy/pmpy/issues). A feature is most likely to be added if you build it!
